Method: Backup::Database::Redis#mode

Defined in:
lib/backup/database/redis.rb

#modeObject

Mode of operation.

:copy

Copies the redis dump file specified by #rdb_path. This data will be current as of the last RDB Snapshot performed by the server (per your redis.conf settings). You may set #invoke_save to true to have Backup issue a SAVE command to update the dump file with the current data before performing the copy.

:sync

Performs a dump of your redis data using redis-cli –rdb -. Redis implements this internally using a SYNC command. The operation is analogous to requesting a BGSAVE, then having the dump returned. This mode is capable of dumping data from a local or remote server. Requires Redis v2.6 or better.

Defaults to :copy.



29
30
31
# File 'lib/backup/database/redis.rb', line 29

def mode
  @mode
end